import { type OptionValues as CliOptionValues } from "commander";
import { AdderDetails, AddersExecutionPlan } from "./execute.js";
export type BooleanDefaultValue = {
    type: "boolean";
    default: boolean;
};
export type StringDefaultValue = {
    type: "string";
    default: string;
};
export type NumberDefaultValue = {
    type: "number";
    default: number;
};
export type BaseQuestion = {
    question: string;
};
export type BooleanQuestion = BaseQuestion & BooleanDefaultValue;
export type StringQuestion = BaseQuestion & StringDefaultValue;
export type NumberQuestion = BaseQuestion & NumberDefaultValue;
export type Question = BooleanQuestion | StringQuestion | NumberQuestion;
export type OptionDefinition = Record<string, Question>;
export type OptionValues<Args extends OptionDefinition> = {
    [K in keyof Args]: Args[K]["type"] extends "string" ? string : Args[K]["type"] extends "boolean" ? boolean : Args[K]["type"] extends "number" ? number : never;
};
export type AvailableCliOptionKeys = keyof AvailableCliOptionKeyTypes;
export type AvailableCliOptionKeyTypes = {
    default: boolean;
    path: string;
    skipPreconditions: boolean;
    skipInstall: boolean;
};
export type AvailableCliOptionValues = {
    [K in AvailableCliOptionKeys]?: AvailableCliOptionKeyTypes[K];
} & {
    adders?: string[];
};
export type AvailableCliOption = {
    cliArg: string;
    processedCliArg: string;
    description: string;
    allowShorthand: boolean;
} & (BooleanDefaultValue | StringDefaultValue);
export type AvailableCliOptions = Record<AvailableCliOptionKeys, AvailableCliOption>;
export declare const availableCliOptions: AvailableCliOptions;
export declare function prepareAndParseCliOptions<Args extends OptionDefinition>(adderDetails: AdderDetails<Args>[]): CliOptionValues;
export declare function ensureCorrectOptionTypes<Args extends OptionDefinition>(adderDetails: AdderDetails<Args>[], cliOptionsByAdderId: Record<string, Record<string, any>>): void;
export declare function extractCommonCliOptions(cliOptions: CliOptionValues): AvailableCliOptionValues;
export declare function extractAdderCliOptions<Args extends OptionDefinition>(cliOptions: CliOptionValues, adderDetails: AdderDetails<Args>[]): Record<string, Record<string, any>>;
export declare function requestMissingOptionsFromUser<Args extends OptionDefinition>(adderDetails: AdderDetails<Args>[], executionPlan: AddersExecutionPlan): Promise<void>;
